@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Stalker a Production Asset Management System
-# Copyright (C) 2009-2013 Erkan Ozgur Yilmaz
+# Copyright (C) 2009-2014 Erkan Ozgur Yilmaz
 #
 # This file is part of Stalker.
 #
@@ -57,7 +57,7 @@ class Ticket(Entity, StatusMixin):
     _`Trac Workflow`:: http://trac.edgewall.org/wiki/TracWorkflow
 
     Stalker Ticket system is very flexible, to customize the workflow please
-    update the :class:`~stalker.config.Config.ticket_workflow` dictionary.
+    update the :class:`.Config.ticket_workflow` dictionary.
 
     In the default setup, there are four actions available; ``accept``,
     ``resolve``, ``reopen``, ``reassign``, and five statuses available ``New``,
@@ -67,7 +67,7 @@ class Ticket(Entity, StatusMixin):
         Stalker must be assigned to a Project. ``project`` argument can not be
         skipped or can not be None.
 
-    :type project: :class:`~stalker.models.project.Project`
+    :type project: :class:`.Project`
 
     :param str summary: A string which contains the title or a short
         description of this Ticket.
@@ -90,18 +90,15 @@ class Ticket(Entity, StatusMixin):
           |              | is fixed                                        |
           +--------------+-------------------------------------------------+
 
-    :param reported_by: An instance of :class:`~stalker.models.user.User` who
-        created this Ticket. It is basically a synonym for the
-        :attr:`~stalker.models.entity.SimpleEntity.created_by` attribute.
+    :param reported_by: An instance of :class:`.User` who created this Ticket.
+      It is basically a synonym for the :attr:`.SimpleEntity.created_by`
+      attribute.
 
-    Changing the :class:`~stalker.models.ticket.Ticket`\ .\
-    :attr`~stalker.models.ticket.Ticket.status` will create a new
-    :class:`~stalker.models.Ticket.TicketLog` instance showing the previous
-    operation.
+    Changing the :class:`.Ticket`\ .\ :attr`.Ticket.status` will create a new
+    :class:`.TicketLog` instance showing the previous operation.
 
     Even though Tickets needs statuses they don't need to be supplied a
-    :class:`~stalker.models.status.StatusList` nor
-    :class:`~stalker.models.status.Status` for the Tickets. It will be
+    :class:`.StatusList` nor :class:`.Status` for the Tickets. It will be
     automatically filled accordingly. For newly created Tickets the status of
     the ticket is ``NEW`` and can be changed to other statuses as follows:
 
@@ -131,21 +128,18 @@ class Ticket(Entity, StatusMixin):
         accept
         reopen
 
-    The :attr:`~stalker.models.ticket.Ticket.name` is automatically generated
-    by using the ``stalker.config.Config.ticket_label`` attribute and
-    :attr:`~stalker.models.ticket.Ticket.ticket_number`\ . So if defaults are
-    used the first ticket name will be "Ticket#1" and the second "Ticket#2" and
-    so on. For every project the number will restart from 1.
+    The :attr:`.Ticket.name` is automatically generated by using the
+    ``stalker.config.Config.ticket_label`` attribute and
+    :attr:`.Ticket.ticket_number`\ . So if defaults are used the first ticket
+    name will be "Ticket#1" and the second "Ticket#2" and so on. For every
+    project the number will restart from 1.
 
-    Use the :meth:`~stalker.models.ticket.Ticket.resolve`,
-    :meth:`~stalker.models.ticket.Ticket.reassign`,
-    :meth:`~stalker.models.ticket.Ticket.accept`,
-    :meth:`~stalker.models.ticket.Ticket.reopen` methods to change the status
+    Use the :meth:`.Ticket.resolve`, :meth:`.Ticket.reassign`,
+    :meth:`.Ticket.accept`, :meth:`.Ticket.reopen` methods to change the status
     of the current Ticket.
 
-    Changing the status of the Ticket will create
-    :class:`~stalker.models.ticket.TicketLog` entries reflecting the change
-    made.
+    Changing the status of the Ticket will create :class:`.TicketLog` entries
+    reflecting the change made.
     """
 
     # logs attribute
@@ -205,9 +199,9 @@ class Ticket(Entity, StatusMixin):
 
     comments = synonym(
         'notes',
-        doc="""A list of :class:`~stalker.models.note.Note` instances showing
-        the comments made for this Ticket instance. It is a synonym for the
-        :attr:`~stalker.models.ticket.Ticket.notes` attribute.
+        doc="""A list of :class:`.Note` instances showing the comments made for
+        this Ticket instance. It is a synonym for the :attr:`.Ticket.notes`
+        attribute.
         """
     )
 
@@ -233,9 +227,9 @@ class Ticket(Entity, StatusMixin):
           |              | enhancement                                     |
           +--------------+-------------------------------------------------+
           | 1 / MINOR    | defect with minor impact / small enhancement    |
-          +--------------+-------------------------------------------------+  
+          +--------------+-------------------------------------------------+
           | 2 / MAJOR    | defect with major impact / big enhancement      |
-          +--------------+-------------------------------------------------+ 
+          +--------------+-------------------------------------------------+
           | 3 / CRITICAL | severe loss of data due to the defect or highly |
           |              | needed enhancement                              |
           +--------------+-------------------------------------------------+
@@ -312,14 +306,17 @@ class Ticket(Entity, StatusMixin):
         """validates the given related_ticket attribute
         """
         if not isinstance(related_ticket, Ticket):
-            raise TypeError('%s.related_ticket attribute should be a list '
-                            'of other stalker.models.ticket.Ticket instances not %s' %
-                            (self.__class__.__name__,
-                             related_ticket.__class__.__name__))
+            raise TypeError(
+                '%s.related_ticket attribute should be a list of other '
+                'stalker.models.ticket.Ticket instances not %s' %
+                (self.__class__.__name__, related_ticket.__class__.__name__)
+            )
 
         if related_ticket is self:
-            raise ValueError('%s.related_ticket attribute can not have '
-                             'itself in the list' % self.__class__.__name__)
+            raise ValueError(
+                '%s.related_ticket attribute can not have itself in the list' %
+                self.__class__.__name__
+            )
 
         return related_ticket
 
@@ -330,10 +327,11 @@ class Ticket(Entity, StatusMixin):
         from stalker import Project
 
         if project is None or not isinstance(project, Project):
-            raise TypeError('%s.project should be an instance of '
-                            'stalker.models.project.Project, not %s' %
-                            (self.__class__.__name__,
-                             project.__class__.__name__))
+            raise TypeError(
+                '%s.project should be an instance of '
+                'stalker.models.project.Project, not %s' %
+                (self.__class__.__name__, project.__class__.__name__)
+            )
 
         return project
 
@@ -344,9 +342,10 @@ class Ticket(Entity, StatusMixin):
         if summary is None:
             summary = ''
         if not isinstance(summary, (str, unicode)):
-            raise TypeError('%s.summary should be an instance of str or '
-                            'unicode, not %s' % (self.__class__.__name__,
-                                                 summary.__class__.__name__))
+            raise TypeError(
+                '%s.summary should be an instance of str or unicode, not %s' %
+                (self.__class__.__name__, summary.__class__.__name__)
+            )
         return summary
 
     def __action__(self, action, created_by, action_arg=None):
@@ -358,7 +357,7 @@ class Ticket(Entity, StatusMixin):
             action
         """
         statuses = defaults.ticket_workflow[action].keys()
-        status = self.status.code.lower()
+        status = self.status.name
         return_value = None
         if status in statuses:
             action_data = defaults.ticket_workflow[action][status]
@@ -429,37 +428,34 @@ class Ticket(Entity, StatusMixin):
                other.number == self.number and \
                other.status == self.status and \
                other.logs == self.logs and \
-               other.priority == self.priority and \
-               other.ticket_for == self.ticket_for
+               other.priority == self.priority
 
 
 class TicketLog(SimpleEntity):
-    """A class to hold :class:`~stalker.models.ticket.Ticket`\ .\ :attr:`~stalker.models.ticket.Ticket.status` change operations.
+    """A class to hold :class:`.Ticket`\ .\ :attr:`.Ticket.status` change operations.
 
-    :param ticket: An instance of :class:`~stalker.models.ticket.Ticket` which
-        the subject to the operation.
+    :param ticket: An instance of :class:`.Ticket` which the subject to the
+      operation.
 
-    :type ticket: :class:`~stalker.models.ticket.Ticket`
+    :type ticket: :class:`.Ticket`
 
-    :param from_status: Holds a reference to a
-        :class:`~stalker.models.status.Status` instance which is the previous
-        status of the :class:`~stalker.models.ticket.Ticket`\ .
+    :param from_status: Holds a reference to a :class:`.Status` instance which
+      is the previous status of the :class:`.Ticket`\ .
 
-    :param to_status: Holds a reference to a
-        :class:`~stalker.models.status.Status` instance which is the new status
-        of the :class;`~stalker.models.ticket.Ticket`\ .
+    :param to_status: Holds a reference to a :class:`.Status` instance which is
+      the new status of the :class;`.Ticket`\ .
 
     :param operation: An Enumerator holding the type of the operation. Possible
-        values are: RESOLVE or REOPEN
+      values are: RESOLVE or REOPEN
 
-        Operations follow the `Track Workflow`_\ , 
+      Operations follow the `Track Workflow`_\ ,
 
-        .. image:: http://trac.edgewall.org/chrome/common/guide/original-workflow.png
-            :width: 787 px
-            :height: 509 px
-            :align: left
+      .. image:: http://trac.edgewall.org/chrome/common/guide/original-workflow.png
+          :width: 787 px
+          :height: 509 px
+          :align: left
 
-    .. _Track Workflow: http://trac.edgewall.org/wiki/TracWorkflow 
+    .. _Track Workflow: http://trac.edgewall.org/wiki/TracWorkflow
     """
 
     # TODO: there are no tests for the TicketLog class
